Description Usage Arguments Value Examples
PowerPoint reporting of a MCA
1 2 3 4 5 6 7 8 9 10 11 12 |
res |
a MCA object |
yes_study_name |
title displayed on the first slide |
path |
path to the directory which will store the PowerPoint file |
file.name |
name of the PowerPoint file |
x1 |
component to plot on the x-axis |
x2 |
component to plot on the y-axis |
thres_x1 |
the threshold for the x-axis over which points are ploted translucent |
thres_x2 |
the threshold for the y-axis over which points are ploted translucent |
proba |
the significance threshold considered to characterized the category (by default 0.05) |
size_tab |
maximum number of rows of a table per slide |
Returns a .pptx file
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.