Yes_PCA: PowerPont reporting of a PCA

Description Usage Arguments Value Examples

View source: R/Yes_PCA.R

Description

PowerPont reporting of a PCA

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
Yes_PCA(
  res,
  yes_study_name = "PCA + HCPC",
  path = getwd(),
  file.name = "PCA_results.pptx",
  x1 = 1,
  x2 = 2,
  proba = 0.05,
  size_tab = 10
)

Arguments

res

a PCA object

yes_study_name

title displayed on the first slide

path

PowerPoint file to be created

file.name

name of the PowerPoint file

x1

component to plot on the x-axis

x2

component to plot on the y-axis

proba

the significance threshold considered to characterized the category (by default 0.05)

size_tab

maximum number of rows of a table per slide

Value

Returns a .pptx file

Examples

1
2
3
4
5
6
7
8
## Not run: 
library(FactoMineR)
data(decathlon)
res.pca <- FactoMineR::PCA(decathlon, quanti.sup = 11:12, quali.sup=13)
# Create the PowerPoint in the current working directory
Yes_PCA(res.pca)

## End(Not run)

MaximeSaland/YesSiR documentation built on Dec. 17, 2021, 3:19 a.m.