Yes_textual: PowerPoint reporting of a textual analysis

Description Usage Arguments Value Examples

View source: R/Yes_textual.R

Description

PowerPoint reporting of a textual analysis

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
Yes_textual(
  res,
  yes_study_name = "Textual analysis",
  path = getwd(),
  file.name = "textual_results.pptx",
  size_tab = 10,
  proba = 0.05,
  col.neg = "red",
  col.pos = "blue"
)

Arguments

res

FactoMineR::textual result

yes_study_name

title displayed on the first slide

path

PowerPoint file to be created

file.name

name of the PowerPoint file

size_tab

maximum number of rows of a table per slide

proba

the significance threshold considered to characterized the category (by default 0.05)

col.neg

color for negative values (on the wordclouds)

col.pos

color for positive values (on the wordclouds)

Value

Returns a .pptx file

Examples

1
2
3
4
5
6
7
## Not run: 
data(beard)
res.text <- textual(beard,contingence.by = 1,num.text = 3)
# Create the PowerPoint in the current working directory
Yes_textual(res.text)

## End(Not run)

MaximeSaland/YesSiR documentation built on Dec. 17, 2021, 3:19 a.m.