Description Usage Arguments Value Examples
PowerPoint reporting of a textual analysis
1 2 3 4 5 6 7 8 9 10 | Yes_textual(
res,
yes_study_name = "Textual analysis",
path = getwd(),
file.name = "textual_results.pptx",
size_tab = 10,
proba = 0.05,
col.neg = "red",
col.pos = "blue"
)
|
res |
FactoMineR::textual result |
yes_study_name |
title displayed on the first slide |
path |
PowerPoint file to be created |
file.name |
name of the PowerPoint file |
size_tab |
maximum number of rows of a table per slide |
proba |
the significance threshold considered to characterized the category (by default 0.05) |
col.neg |
color for negative values (on the wordclouds) |
col.pos |
color for positive values (on the wordclouds) |
Returns a .pptx file
1 2 3 4 5 6 7 | ## Not run:
data(beard)
res.text <- textual(beard,contingence.by = 1,num.text = 3)
# Create the PowerPoint in the current working directory
Yes_textual(res.text)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.